@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::AutoRoutePm;
-$Mojolicious::Plugin::AutoRoutePm::VERSION = '0.13';
+
 use Mojo::Base 'Mojolicious::Plugin';
 # ABSTRACT: Mojolicious plugin to create routes by *.pm modules which are a controller
 
@@ -25,8 +25,9 @@ sub register {
 	# removing it we got the base path
 	my $template_base_dirs = [];
 	foreach (@$system_template_base_dirs) {
-		s/templates$//;
-		push @$template_base_dirs, $_;
+        my $tmpl_base_dir = $_; # so next replace doesn't affect origianl path
+		$tmpl_base_dir =~ s/templates$//;
+		push @$template_base_dirs, $tmpl_base_dir;
 	}
   # Top directory
   my $top_dir = $conf->{top_dir} || '.';
@@ -121,24 +122,10 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Mojolicious::Plugin::AutoRoutePm - Mojolicious plugin to create routes by *.pm modules which are a controller
 
-=head1 VERSION
-
-version 0.13
-
-=head1 METHODS
-
-=head2 register
-
-  plugin->register($app);
-
-Register plugin in L<Mojolicious> application.
-
 =head1 USAGE
 
 This module recursive passes through template_base_dir to find perl module
@@ -166,17 +153,27 @@ a base_url like this
   % my $base_url = url_for(undef, {query => undef}); $base_url =~ s|/$||;
   <base href="<%= $base_url %>" />
 
+=head2 register
+
+  plugin->register($app);
+
+Register plugin in L<Mojolicious> application.
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
 
+=head1 VERSION
+
+version 0.14
+
 =head1 AUTHOR
 
 Emiliano Bruni <info@ebruni.it>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Emiliano Bruni.
+This software is copyright (c) 2021 by Emiliano Bruni.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
